@@ -375,7 +375,8 @@ modMAarea <- function(MApopdat,
   adjcase <- MApopdat$adjcase
   pltidsid <- MApopdat$pjoinid
   pltassgnid <- MApopdat$pltassgnid
- 
+  pltcondflds <- MApopdat$pltcondflds
+  
   if (MAmethod %in% c("greg", "gregEN", "ratio")) {
     if (is.null(prednames)) {
       prednames <- MApopdat$prednames
@@ -433,6 +434,7 @@ modMAarea <- function(MApopdat,
                   popdatindb = popdatindb,
                   popconn = popconn, pop_schema = pop_schema,
                   pltcondx = pltcondx,
+                  pltcondflds = pltcondflds,
                   totals = totals,
                   pop_fmt=pop_fmt, pop_dsn=pop_dsn,
                   landarea = landarea,
@@ -469,7 +471,7 @@ modMAarea <- function(MApopdat,
   SCHEMA. <- estdat$SCHEMA.
   pltcondflds <- estdat$pltcondflds
   
-
+  
   ###################################################################################
   ### GET ROW AND COLUMN INFO FROM condf
   ###################################################################################
@@ -491,7 +493,7 @@ modMAarea <- function(MApopdat,
                  rowlut = rowlut, collut = collut, 
                  rowgrp = rowgrp, rowgrpnm = rowgrpnm, 
                  rowgrpord = rowgrpord, title.rowgrp = NULL,
-                 gui = gui)
+                 whereqry = pcwhereqry)
   uniquerow <- rowcolinfo$uniquerow
   uniquecol <- rowcolinfo$uniquecol
   bydomainlst <- rowcolinfo$domainlst
